@@ -162,7 +162,7 @@ Description=Skitai {name} Service
 After=syslog.target network.target
 
 [Service]
-Type=forking
+Type=simple
 PIDFile=/var/run/{pidfile}.pid
 WorkingDirectory={working_dir}
 User={user}
